@@ -70,7 +70,7 @@
 #define yychar          i386_char
 
 /* Copy the first part of user declarations.  */
-#line 1 "i386_parse.y" /* yacc.c:339  */
+#line 1 "/home/mark/src/elfutils/libcpu/i386_parse.y" /* yacc.c:339  */
 
 /* Parser for i386 CPU description.
    Copyright (C) 2004, 2005, 2007, 2008, 2009 Red Hat, Inc.
@@ -350,7 +350,7 @@ extern int i386_debug;
 
 union YYSTYPE
 {
-#line 217 "i386_parse.y" /* yacc.c:355  */
+#line 217 "/home/mark/src/elfutils/libcpu/i386_parse.y" /* yacc.c:355  */
 
   unsigned long int num;
   char *str;
@@ -1474,7 +1474,7 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 248 "i386_parse.y" /* yacc.c:1646  */
+#line 248 "/home/mark/src/elfutils/libcpu/i386_parse.y" /* yacc.c:1646  */
     {
 		      if (error_message_count != 0)
 			error (EXIT_FAILURE, 0,
@@ -1486,25 +1486,25 @@ yyreduce:
     break;
 
   case 5:
-#line 262 "i386_parse.y" /* yacc.c:1646  */
+#line 262 "/home/mark/src/elfutils/libcpu/i386_parse.y" /* yacc.c:1646  */
     { new_bitfield ((yyvsp[-1].str), (yyvsp[0].num)); }
 #line 1492 "i386_parse.c" /* yacc.c:1646  */
     break;
 
   case 6:
-#line 264 "i386_parse.y" /* yacc.c:1646  */
+#line 264 "/home/mark/src/elfutils/libcpu/i386_parse.y" /* yacc.c:1646  */
     { new_bitfield ((yyvsp[0].str), -1); }
 #line 1498 "i386_parse.c" /* yacc.c:1646  */
     break;
 
   case 7:
-#line 266 "i386_parse.y" /* yacc.c:1646  */
+#line 266 "/home/mark/src/elfutils/libcpu/i386_parse.y" /* yacc.c:1646  */
     { new_bitfield ((yyvsp[0].str), -2); }
 #line 1504 "i386_parse.c" /* yacc.c:1646  */
     break;
 
   case 8:
-#line 268 "i386_parse.y" /* yacc.c:1646  */
+#line 268 "/home/mark/src/elfutils/libcpu/i386_parse.y" /* yacc.c:1646  */
     {
 		      struct synonym *newp = xmalloc (sizeof (*newp));
 		      newp->from = (yyvsp[-1].str);
@@ -1520,7 +1520,7 @@ yyreduce:
     break;
 
   case 12:
-#line 287 "i386_parse.y" /* yacc.c:1646  */
+#line 287 "/home/mark/src/elfutils/libcpu/i386_parse.y" /* yacc.c:1646  */
     {
 		      if ((yyvsp[-3].field) != NULL && strcmp ((yyvsp[-3].field)->name, "RE") != 0
 			  && strcmp ((yyvsp[-3].field)->name, "R") != 0)
@@ -1607,7 +1607,7 @@ yyreduce:
     break;
 
   case 14:
-#line 373 "i386_parse.y" /* yacc.c:1646  */
+#line 373 "/home/mark/src/elfutils/libcpu/i386_parse.y" /* yacc.c:1646  */
     {
 		      struct known_bitfield search;
 		      search.name = (yyvsp[0].str);
@@ -1626,13 +1626,13 @@ yyreduce:
     break;
 
   case 15:
-#line 388 "i386_parse.y" /* yacc.c:1646  */
+#line 388 "/home/mark/src/elfutils/libcpu/i386_parse.y" /* yacc.c:1646  */
     { (yyval.field) = NULL; }
 #line 1632 "i386_parse.c" /* yacc.c:1646  */
     break;
 
   case 16:
-#line 392 "i386_parse.y" /* yacc.c:1646  */
+#line 392 "/home/mark/src/elfutils/libcpu/i386_parse.y" /* yacc.c:1646  */
     {
 		      check_bits ((yyvsp[0].bit));
 
@@ -1646,7 +1646,7 @@ yyreduce:
     break;
 
   case 17:
-#line 402 "i386_parse.y" /* yacc.c:1646  */
+#line 402 "/home/mark/src/elfutils/libcpu/i386_parse.y" /* yacc.c:1646  */
     {
 		      check_bits ((yyvsp[0].bit));
 		      (yyval.bit) = (yyvsp[0].bit);
@@ -1655,7 +1655,7 @@ yyreduce:
     break;
 
   case 18:
-#line 409 "i386_parse.y" /* yacc.c:1646  */
+#line 409 "/home/mark/src/elfutils/libcpu/i386_parse.y" /* yacc.c:1646  */
     {
 		      struct bitvalue *runp = (yyvsp[-1].bit);
 		      while (runp->next != NULL)
@@ -1667,13 +1667,13 @@ yyreduce:
     break;
 
   case 19:
-#line 417 "i386_parse.y" /* yacc.c:1646  */
+#line 417 "/home/mark/src/elfutils/libcpu/i386_parse.y" /* yacc.c:1646  */
     { (yyval.bit) = (yyvsp[0].bit); }
 #line 1673 "i386_parse.c" /* yacc.c:1646  */
     break;
 
   case 20:
-#line 421 "i386_parse.y" /* yacc.c:1646  */
+#line 421 "/home/mark/src/elfutils/libcpu/i386_parse.y" /* yacc.c:1646  */
     {
 		      (yyval.bit) = xmalloc (sizeof (struct bitvalue));
 		      (yyval.bit)->type = zeroone;
@@ -1684,7 +1684,7 @@ yyreduce:
     break;
 
   case 21:
-#line 428 "i386_parse.y" /* yacc.c:1646  */
+#line 428 "/home/mark/src/elfutils/libcpu/i386_parse.y" /* yacc.c:1646  */
     {
 		      (yyval.bit) = xmalloc (sizeof (struct bitvalue));
 		      (yyval.bit)->type = zeroone;
@@ -1695,7 +1695,7 @@ yyreduce:
     break;
 
   case 22:
-#line 435 "i386_parse.y" /* yacc.c:1646  */
+#line 435 "/home/mark/src/elfutils/libcpu/i386_parse.y" /* yacc.c:1646  */
     {
 		      (yyval.bit) = xmalloc (sizeof (struct bitvalue));
 		      struct known_bitfield search;
@@ -1719,19 +1719,19 @@ yyreduce:
     break;
 
   case 23:
-#line 457 "i386_parse.y" /* yacc.c:1646  */
+#line 457 "/home/mark/src/elfutils/libcpu/i386_parse.y" /* yacc.c:1646  */
     { (yyval.arg) = (yyvsp[0].arg); }
 #line 1725 "i386_parse.c" /* yacc.c:1646  */
     break;
 
   case 24:
-#line 459 "i386_parse.y" /* yacc.c:1646  */
+#line 459 "/home/mark/src/elfutils/libcpu/i386_parse.y" /* yacc.c:1646  */
     { (yyval.arg) = NULL; }
 #line 1731 "i386_parse.c" /* yacc.c:1646  */
     break;
 
   case 25:
-#line 463 "i386_parse.y" /* yacc.c:1646  */
+#line 463 "/home/mark/src/elfutils/libcpu/i386_parse.y" /* yacc.c:1646  */
     {
 		      struct argument *runp = (yyvsp[-2].arg);
 		      while (runp->next != NULL)
@@ -1745,7 +1745,7 @@ yyreduce:
     break;
 
   case 26:
-#line 473 "i386_parse.y" /* yacc.c:1646  */
+#line 473 "/home/mark/src/elfutils/libcpu/i386_parse.y" /* yacc.c:1646  */
     {
 		      (yyval.arg) = xmalloc (sizeof (struct argument));
 		      (yyval.arg)->name = combine ((yyvsp[0].name));
@@ -1755,7 +1755,7 @@ yyreduce:
     break;
 
   case 27:
-#line 481 "i386_parse.y" /* yacc.c:1646  */
+#line 481 "/home/mark/src/elfutils/libcpu/i386_parse.y" /* yacc.c:1646  */
     {
 		      struct argname *runp = (yyvsp[-1].name);
 		      while (runp->next != NULL)
@@ -1767,13 +1767,13 @@ yyreduce:
     break;
 
   case 28:
-#line 489 "i386_parse.y" /* yacc.c:1646  */
+#line 489 "/home/mark/src/elfutils/libcpu/i386_parse.y" /* yacc.c:1646  */
     { (yyval.name) = (yyvsp[0].name); }
 #line 1773 "i386_parse.c" /* yacc.c:1646  */
     break;
 
   case 29:
-#line 492 "i386_parse.y" /* yacc.c:1646  */
+#line 492 "/home/mark/src/elfutils/libcpu/i386_parse.y" /* yacc.c:1646  */
     {
 		      (yyval.name) = xmalloc (sizeof (struct argname));
 		      (yyval.name)->type = nfield;
@@ -1809,7 +1809,7 @@ yyreduce:
     break;
 
   case 30:
-#line 524 "i386_parse.y" /* yacc.c:1646  */
+#line 524 "/home/mark/src/elfutils/libcpu/i386_parse.y" /* yacc.c:1646  */
     {
 		      (yyval.name) = xmalloc (sizeof (struct argname));
 		      (yyval.name)->type = string;
@@ -1822,7 +1822,7 @@ yyreduce:
     break;
 
   case 31:
-#line 533 "i386_parse.y" /* yacc.c:1646  */
+#line 533 "/home/mark/src/elfutils/libcpu/i386_parse.y" /* yacc.c:1646  */
     {
 		      (yyval.name) = xmalloc (sizeof (struct argname));
 		      (yyval.name)->type = string;
@@ -1833,7 +1833,7 @@ yyreduce:
     break;
 
   case 32:
-#line 540 "i386_parse.y" /* yacc.c:1646  */
+#line 540 "/home/mark/src/elfutils/libcpu/i386_parse.y" /* yacc.c:1646  */
     {
 		      (yyval.name) = xmalloc (sizeof (struct argname));
 		      (yyval.name)->type = string;
@@ -2074,7 +2074,7 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 550 "i386_parse.y" /* yacc.c:1906  */
+#line 550 "/home/mark/src/elfutils/libcpu/i386_parse.y" /* yacc.c:1906  */
 
 
 static void
